@@ -31,12 +31,14 @@ import keyboard_models
 
 class Keyboard(SimpleConfigFile):
     def __init__(self):
+        self._mods = keyboard_models.KeyboardModels()
+
         self.type = "PC"
         self.beenset = 0
         self.info = {}
 
         # default to us
-        self.info["KEYTABLE"] = "us"
+        self.set("us")
 
         try:
             bus = dbus.SystemBus()
@@ -46,22 +48,25 @@ class Keyboard(SimpleConfigFile):
                 self.type = "Serial"
             else:
                 self.info["KEYBOARDTYPE"] = "pc"
-            kb = dbus.Interface(bus.get_object("org.freedesktop.Hal", kbs[0], 'org.freedesktop.Hal.Device'))
+            kb = dbus.Interface(bus.get_object("org.freedesktop.Hal", kbs[0]), 'org.freedesktop.Hal.Device')
             if kb.GetPropertyString("info.product").startswith("Sun Type"):
                 self.type == "Sun"
                 self.info["KEYBOARDTYPE"] = "sun"
         except:
             pass
 
-        self._mods = keyboard_models.KeyboardModels()
-
     def _get_models(self):
         return self._mods.get_models()
     modelDict = property(_get_models)
 
     def set(self, keytable):
         if self.type != "Serial":
+            kb = self.modelDict[keytable]
             self.info["KEYTABLE"] = keytable
+            self.info["MODEL"] = kb[2]
+            self.info["LAYOUT"] = kb[1]
+            self.info["VARIANT"] = kb[3]
+            self.info["OPTIONS"] = kb[4]
 
     def get(self):
         return self.info["KEYTABLE"]
@@ -103,7 +108,7 @@ class Keyboard(SimpleConfigFile):
     def write(self, instPath = "/"):
         SimpleConfigFile.write(self, instPath + "/etc/sysconfig/keyboard")
         try:
-	    os.unlink(instPath + "/etc/sysconfig/console/default.kmap")
+            os.unlink(instPath + "/etc/sysconfig/console/default.kmap")
         except:
             pass
 
@@ -141,7 +146,7 @@ class Keyboard(SimpleConfigFile):
         if not os.environ.has_key("DISPLAY"):
             return
 
-        argv = [ "/usr/bin/setxkbmap", "-layout", layout, "-model", model ]
+        argv = [ "/usr/bin/setxkbmap", "-layout", layout ]
 
         # XXX setxkbmap(1) needs one -option flag for each option
         if options:
