@@ -45,34 +45,34 @@ class KeyboardModels:
         self._modelDict = {
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ar-azerty'               : [N_('keyboard|Arabic (azerty)'), 'us,ara', 'pc105', 'azerty', 'grp:shifts_toggle,grp_led:scroll'],
+            'ar-azerty'               : [N_('keyboard|Arabic (azerty)'), 'ara,us', 'pc105', 'azerty', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ar-azerty-digits'        : [N_('keyboard|Arabic (azerty/digits)'), 'us,ara', 'pc105', 'azerty_digits', 'grp:shifts_toggle,grp_led:scroll'],
+            'ar-azerty-digits'        : [N_('keyboard|Arabic (azerty/digits)'), 'ara,us', 'pc105', 'azerty_digits', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ar-digits'               : [N_('keyboard|Arabic (digits)'), 'us,ara', 'pc105', 'digits', 'grp:shifts_toggle,grp_led:scroll'],
+            'ar-digits'               : [N_('keyboard|Arabic (digits)'), 'ara,us', 'pc105', 'digits', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ar-qwerty'               : [N_('keyboard|Arabic (qwerty)'), 'us,ara', 'pc105', 'qwerty', 'grp:shifts_toggle,grp_led:scroll'],
+            'ar-qwerty'               : [N_('keyboard|Arabic (qwerty)'), 'ara,us', 'pc105', 'qwerty', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ar-qwerty-digits'        : [N_('keyboard|Arabic (qwerty/digits)'), 'us,ara', 'pc105', 'qwerty_digits', 'grp:shifts_toggle,grp_led:scroll'],
+            'ar-qwerty-digits'        : [N_('keyboard|Arabic (qwerty/digits)'), 'ara,us', 'pc105', 'qwerty_digits', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'be-latin1'               : [N_('keyboard|Belgian (be-latin1)'), 'be', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ben'                      : [N_('keyboard|Bengali (Inscript)'), 'us,in', 'pc105', 'ben', 'grp:shifts_toggle,grp_led:scroll'],
+            'ben'                      : [N_('keyboard|Bengali (Inscript)'), 'in,us', 'pc105', 'ben', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ben-probhat'             : [N_('keyboard|Bengali (Probhat)'), 'us,in', 'pc105', 'ben_probhat', 'grp:shifts_toggle,grp_led:scroll'],
+            'ben-probhat'             : [N_('keyboard|Bengali (Probhat)'), 'in,us', 'pc105', 'ben_probhat', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'bg_bds-utf8'             : [N_('keyboard|Bulgarian'), 'us,bg', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'bg_bds-utf8'             : [N_('keyboard|Bulgarian'), 'bg,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'bg_pho-utf8'             : [N_('keyboard|Bulgarian (Phonetic)'), 'us,bg', 'pc105', ',phonetic', 'grp:shifts_toggle,grp_led:scroll'],
+            'bg_pho-utf8'             : [N_('keyboard|Bulgarian (Phonetic)'), 'bg,us', 'pc105', ',phonetic', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'br-abnt2'                : [N_('keyboard|Brazilian (ABNT2)'), 'br', 'abnt2', '', ''],
@@ -84,7 +84,7 @@ class KeyboardModels:
             'croat'                   : [N_('keyboard|Croatian'), 'hr', 'pc105', '', '' ],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'cz-us-qwertz'            : [N_('keyboard|Czech'), 'us,cz', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'cz-us-qwertz'            : [N_('keyboard|Czech'), 'cz,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'cz-lat2'                 : [N_('keyboard|Czech (qwerty)'), 'cz', 'pc105', 'qwerty', ''],
@@ -99,7 +99,7 @@ class KeyboardModels:
             'de-latin1-nodeadkeys'    : [N_('keyboard|German (latin1 w/ no deadkeys)'), 'de', 'pc105', 'nodeadkeys', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'dev'                     : [N_('keyboard|Devanagari (Inscript)'), 'us,dev', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'dev'                     : [N_('keyboard|Devanagari (Inscript)'), 'dev,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
            'dvorak'                   : [N_('keyboard|Dvorak'), 'us', 'pc105', 'dvorak', ''],
@@ -135,25 +135,28 @@ class KeyboardModels:
             'fr-pc'                   : [N_('keyboard|French (pc)'), 'fr', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'fr_CH'                   : [N_('keyboard|Swiss French'), 'fr_CH', 'pc105', '', ''],
+            'fr_CH'                   : [N_('keyboard|Swiss French'), 'ch', 'pc105', 'fr', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'fr_CH-latin1'            : [N_('keyboard|Swiss French (latin1)'), 'ch', 'pc105', 'fr', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'gr'                      : [N_('keyboard|Greek'), 'us,gr', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'gr'                      : [N_('keyboard|Greek'), 'gr,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'guj'                     : [N_('keyboard|Gujarati (Inscript)'), 'us,in', 'pc105', 'guj', 'grp:shifts_toggle,grp_led:scroll'],
+            'guj'                     : [N_('keyboard|Gujarati (Inscript)'), 'in,us', 'pc105', 'guj', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'gur'                     : [N_('keyboard|Punjabi (Inscript)'), 'us,gur', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'gur'                     : [N_('keyboard|Punjabi (Inscript)'), 'gur,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'hu'                      : [N_('keyboard|Hungarian'), 'hu', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'hu101'                   : [N_('keyboard|Hungarian (101 key)'), 'hu', 'pc105', 'qwerty', ''],
+            'ie'                      : [N_('keyboard|Irish'), 'ie', 'pc105', '', ''],
+            # Translators: the word before the bar is just context and
+            # doesn't need to be translated. Only after will be translated.
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'is-latin1'               : [N_('keyboard|Icelandic'), 'is', 'pc105', '', ''],
@@ -177,7 +180,7 @@ class KeyboardModels:
             'la-latin1'               : [N_('keyboard|Latin American'), 'latam', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'mk-utf'                  : [N_('keyboard|Macedonian'), 'us,mkd', 'pc105', '','grp:shifts_toggle,grp_led:scroll'],
+            'mk-utf'                  : [N_('keyboard|Macedonian'), 'mkd,us', 'pc105', '','grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'nl'                      : [N_('keyboard|Dutch'), 'nl', 'pc105', '', ''],
@@ -195,7 +198,16 @@ class KeyboardModels:
             'ro'                  : [N_('keyboard|Romanian'), 'ro', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ru'                      : [N_('keyboard|Russian'), 'us,ru', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'ro-std'                  : [N_('keyboard|Romanian Standard'), 'ro', 'pc105', 'std', ''],
+            # Translators: the word before the bar is just context and
+            # doesn't need to be translated. Only after will be translated.
+            'ro-cedilla'                  : [N_('keyboard|Romanian Cedilla'), 'ro', 'pc105', 'cedilla', ''],
+            # Translators: the word before the bar is just context and
+            # doesn't need to be translated. Only after will be translated.
+            'ro-std-cedilla'                  : [N_('keyboard|Romanian Standard Cedilla'), 'ro', 'pc105', 'std_cedilla', ''],
+            # Translators: the word before the bar is just context and
+            # doesn't need to be translated. Only after will be translated.
+            'ru'                      : [N_('keyboard|Russian'), 'ru,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'sr-cy'                 : [N_('keyboard|Serbian'), 'rs', 'pc105', '', ''],
@@ -219,10 +231,13 @@ class KeyboardModels:
             'slovene'                 : [N_('keyboard|Slovenian'), 'si', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'tml-inscript'            : [N_('keyboard|Tamil (Inscript)'), 'us,in', 'pc105', 'tam', 'grp:shifts_toggle,grp_led:scroll'],
+            'tj'                      : [N_('keyboard|Tajik'), 'tj', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'tml-uni'                 : [N_('keyboard|Tamil (Typewriter)'), 'us,in', 'pc105', 'tam_TAB', 'grp:shifts_toggle,grp_led:scroll'],
+            'tml-inscript'            : [N_('keyboard|Tamil (Inscript)'), 'in,us', 'pc105', 'tam', 'grp:shifts_toggle,grp_led:scroll'],
+            # Translators: the word before the bar is just context and
+            # doesn't need to be translated. Only after will be translated.
+            'tml-uni'                 : [N_('keyboard|Tamil (Typewriter)'), 'in,us', 'pc105', 'tam_TAB', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'trq'                     : [N_('keyboard|Turkish'), 'tr', 'pc105', '', ''],
@@ -231,13 +246,13 @@ class KeyboardModels:
             'uk'                      : [N_('keyboard|United Kingdom'), 'gb', 'pc105', '', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'ua-utf'                  : [N_('keyboard|Ukrainian'), 'us,ua', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
+            'ua-utf'                  : [N_('keyboard|Ukrainian'), 'ua,us', 'pc105', '', 'grp:shifts_toggle,grp_led:scroll'],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
             'us-acentos'              : [N_('keyboard|U.S. International'), 'us', 'pc105', 'intl', ''],
             # Translators: the word before the bar is just context and
             # doesn't need to be translated. Only after will be translated.
-            'us'                      : [N_('keyboard|U.S. English'), 'us', 'pc105', '', ''],
+            'us'                      : [N_('keyboard|U.S. English'), 'us', 'pc105+inet', '', ''],
             }
 
     def _get_models(self):
